@@ -7,9 +7,7 @@ def get_mouse_pos():
   return (pos.x, pos.y)
   
 if __name__ == "__main__":
-  print (get_mouse_pos())
+  while 1:
+    print (get_mouse_pos())
+    
 
-"""
-
-
-if __name__ == "__main__":
\ No newline at end of file
